@@ -62,6 +62,14 @@ atoms = [
         (lambda_max, (1, 1), [ [[2,0],[0,1]] ], Constant([2])),
         (lambda_max, (1, 1), [ [[5,7],[7,-3]] ], Constant([9.06225775])),
         (log_sum_exp, (1, 1), [ [[5, 7], [0, -3]] ], Constant([7.1277708268])),
+        (matrix_frac, (1, 1), [ [1, 2, 3],
+                            [[1, 0, 0],
+                             [0, 1, 0],
+                             [0, 0, 1]] ], Constant([14])),
+        (matrix_frac, (1, 1), [ [1, 2, 3],
+                            [[67, 78, 90],
+                             [78, 94, 108],
+                             [90, 108, 127]] ], Constant([0.46557377049180271])),
         (max_elemwise, (2, 1), [ [-5,2],[-3,1],0,[-1,2] ], Constant([0,2])),
         (max_elemwise, (2, 2), [ [[-5,2],[-3,1]],0,[[5,4],[-1,2]] ],
             Constant([[5,4],[0,2]])),
