@@ -108,7 +108,7 @@ class TestProblem(BaseTest):
         for verbose in [True, False]:
             for solver in [s.ECOS, s.CVXOPT, s.SCS]:
                 sys.stdout = StringIO()     # capture output
-                p = Problem(Minimize(self.a), [self.a >= 2])
+                p = Problem(Minimize(self.a + self.x[0]), [self.a >= 2, self.x >= 2])
                 p.solve(verbose=verbose, solver=solver)
                 if solver != s.ECOS:
                     p = Problem(Minimize(self.a), [log(self.a) >= 2])
@@ -722,6 +722,13 @@ class TestProblem(BaseTest):
             p.solve()
         self.assertEqual(str(cm.exception), "Problem does not follow DCP rules.")
 
+    def test_bad_objective(self):
+        """Test using a cvxpy expression as an objective.
+        """
+        with self.assertRaises(Exception) as cm:
+            Problem(self.x+2)
+        self.assertEqual(str(cm.exception), "Problem objective must be Minimize or Maximize.")
+
     # Test variable transpose.
     def test_transpose(self):
         p = Problem(Minimize(sum_entries(self.x)), [self.x.T >= matrix([1,2]).T])
